from distutils.core import setup

setup(
	name		= 'keithster',
	version		= '1.1.0',
	py_modules	= ['keithster'],
	author		= 'khaddock',
	author_email 	= 'khadd007@gmail.com',
	url		= 'http://www.headfirstlabs.com',
	description	= 'A simple printer of nested lists',
	)

